==> spring-data-aerospike-3.0.1-sources.jar: org/springframework/data/aerospike/annotation/Expiration.java <==
/*
 * Copyright 2016 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.data.aerospike.annotation;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Demarcates a property to be used as expiration field.
 * Expiration can be specified in two flavors: as an offset in seconds from the current time or as an absolute Unix time stamp.
 * <br/><br/>
 * Client system time must be synchronized with aerospike server system time,
 * otherwise expiration behaviour will be unpredictable.
 */
@Documented
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.FIELD)
public @interface Expiration {

	/**
	 * An optional flag indicating whether the expiration is specified as Unix time.
	 * By default an offset in seconds from the current time is used.
	 */
	boolean unixTime() default false;
}

==> spring-data-aerospike-4.1.0-sources.jar: org/springframework/data/aerospike/annotation/Expiration.java <==
/*
 * Copyright 2016 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.data.aerospike.annotation;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Demarcates a property to be used as expiration field. Expiration can be specified in two flavors: as an offset in
 * seconds from the current time or as an absolute Unix time stamp. <br/><br/> Client system time must be synchronized
 * with aerospike server system time, otherwise expiration behaviour will be unpredictable.
 */
@Documented
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.FIELD)
public @interface Expiration {

    /**
     * An optional flag indicating whether the expiration is specified as Unix time. By default, an offset in seconds
     * from the current time is used.
     */
    boolean unixTime() default false;
}
